@@ -7,17 +7,17 @@
 #' @examples
 #'
 #' # Floppy eyelid syndrome vs obstructive sleep apnea (Ezra et al., 2010)
-#' n <- rbind(c(7,25),c(2,68))
+#' n <- rbind(c(7, 25), c(2, 68))
 #' Transformed_Wilson_score_CI_paired_2x2(n)
 #'
 #' @export
 #' @return A list containing lower, upper and point estimates of the statistic
-Transformed_Wilson_score_CI_paired_2x2 <- function(n, alpha=0.05, printresults=TRUE) {
+Transformed_Wilson_score_CI_paired_2x2 <- function(n, alpha = 0.05, printresults = TRUE) {
   # Estimate of the conditional odds ratio (thetacondhat)
   estimate <- n[1, 2] / n[2, 1]
 
   # The Wilson score interval for mu <- pi_12 / (pi_12 + pi_21)
-  tmp <- Wilson_score_CI_1x2(n[1, 2], n[1, 2] + n[2, 1], alpha, F)
+  tmp <- Wilson_score_CI_1x2(n[1, 2], n[1, 2] + n[2, 1], alpha, FALSE)
   L_mu <- tmp[[1]]
   U_mu <- tmp[[2]]
 
@@ -26,12 +26,12 @@ Transformed_Wilson_score_CI_paired_2x2 <- function(n, alpha=0.05, printresults=T
   U <- U_mu / (1 - U_mu)
 
   if (printresults) {
-    .print('The transformed Wilson score CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)\n', estimate, 100 * (1 - alpha), L, U)
+    .print("The transformed Wilson score CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)\n", estimate, 100 * (1 - alpha), L, U)
   }
 
-  invisible(list(L=L,U=U,estimate=estimate))
+  invisible(list(L = L, U = U, estimate = estimate))
 }
 
 .print <- function(s, ...) {
-  print(sprintf(gsub('\n','',s), ...), quote=FALSE)
+  print(sprintf(gsub("\n", "", s), ...), quote = FALSE)
 }
